.split-left-template-selector[data-v-27d106d0]{padding-right:10px;background-color:#fff}.split-left-template-selector .ivu-form-item[data-v-27d106d0]{margin-bottom:0;padding-bottom:5px}.attachment-line{height:32px!important}.attachment-item{display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;-webkit-box-orient:horizontal;-ms-flex-direction:row;flex-direction:row;-ms-flex-line-pack:center;align-content:center;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-ms-flex-align:center;align-items:center;width:100%}.attachment-item,.attachment-name{-webkit-box-direction:normal;height:32px}.attachment-name{display:-webkit-box!important;display:-ms-flexbox!important;display:flex!important;-webkit-box-orient:vertical;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;width:80%}.attachment-name .ivu-tooltip{display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex}.attachment-name .ivu-tooltip .ivu-tooltip-rel{width:-webkit-fill-available!important;overflow:hidden;text-overflow:ellipsis;word-break:keep-all;padding-right:3px}.attachment-actions{width:20%;height:32px;overflow:auto;-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;display:-webkit-box;display:-ms-flexbox;display:flex;padding-right:2px}.flex_input{position:absolute}.ivu-tooltip[data-v-0e55e3a5]{display:inline-block;width:100%}.split-left-form[data-v-7f769ec6]{height:calc(100vh - 89px);overflow-y:auto;overflow-x:auto;border-bottom:1px solid #dcdee2;padding-right:10px;white-space:nowrap}.split-left-form .ivu-form-item[data-v-7f769ec6]{margin-bottom:12px}.split-right-bar[data-v-c4b90b78]{height:32px;overflow-x:auto;overflow-y:hidden;white-space:nowrap;border-bottom:1px solid #dcdee2;line-height:32px}.device-btn-group[data-v-c4b90b78]{margin:2px 2px}.device-btn[data-v-c4b90b78]{border:1px solid #c3d9ee;border-radius:3px 0 0 3px;background:#fff;cursor:pointer;padding:2px 5px}.screenshot-btn[data-v-c4b90b78]{border:1px solid #c3d9ee;border-left:0;border-radius:0 3px 3px 0;background:#fff;cursor:pointer;padding:2px 5px}.contextmenu-item{display:-webkit-box;display:-ms-flexbox;display:flex;min-height:40px;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.contextmenu-item-container{display:block}.title[data-v-09affdc8]{font-size:14px}.info[data-v-09affdc8]{color:#696969;font-size:12px}.tag[data-v-09affdc8]{color:green}.property_font[data-v-09affdc8]{font-size:12px;font-weight:700;color:#aeaeae;padding-left:5px;padding-right:5px}.description[data-v-14c96c95]{white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.page{text-align:center;margin-top:5px}.event-table .ivu-table-cell{padding-left:3px;padding-right:3px}.row-contextmenu{position:absolute}.split-right-table[data-v-3a452848]{height:calc(100vh - 28px);overflow-y:auto;border-bottom:1px solid #dcdee2}.demo-split[data-v-3a452848]{height:200px;border:1px solid #dcdee2}.demo-split-pane[data-v-3a452848]{padding:10px;overflow-y:auto;height:100%}.bugit-split[data-v-3d90b184]{height:100vh}#app{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;color:#2c3e50}